pub struct UnixStream { /* private fields */ }uds only.Expand description
A structure representing a connected Unix socket.
This socket can be connected directly with UnixStream::connect or accepted
from a listener with UnixListener::incoming. Additionally, a pair of
anonymous Unix sockets can be created with UnixStream::pair.
Implementations
Sourceimpl UnixStream
impl UnixStream
Sourcepub async fn connect<P>(path: P) -> Result<UnixStream>
pub async fn connect<P>(path: P) -> Result<UnixStream>
Connects to the socket named by path.
This function will create a new Unix socket and connect to the path specified, associating the returned stream with the default event loop’s handle.
Sourcepub fn from_std(stream: UnixStream) -> Result<UnixStream>
pub fn from_std(stream: UnixStream) -> Result<UnixStream>
Consumes a UnixStream in the standard library and returns a
nonblocking UnixStream from this crate.
The returned stream will be associated with the given event loop
specified by handle and is ready to perform I/O.
Panics
This function panics if thread-local runtime is not set.
The runtime is usually set implicitly when this function is called
from a future driven by a tokio runtime, otherwise runtime can be set
explicitly with Handle::enter function.
Sourcepub fn pair() -> Result<(UnixStream, UnixStream)>
pub fn pair() -> Result<(UnixStream, UnixStream)>
Creates an unnamed pair of connected sockets.
This function will create a pair of interconnected Unix sockets for communicating back and forth between one another. Each socket will be associated with the default event loop’s handle.
Sourcepub fn local_addr(&self) -> Result<SocketAddr>
pub fn local_addr(&self) -> Result<SocketAddr>
Returns the socket address of the local half of this connection.
Sourcepub fn peer_addr(&self) -> Result<SocketAddr>
pub fn peer_addr(&self) -> Result<SocketAddr>
Returns the socket address of the remote half of this connection.
Sourcepub fn peer_cred(&self) -> Result<UCred>
pub fn peer_cred(&self) -> Result<UCred>
Returns effective credentials of the process which called connect or pair.
Sourcepub fn take_error(&self) -> Result<Option<Error>>
pub fn take_error(&self) -> Result<Option<Error>>
Returns the value of the SO_ERROR option.